@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2010  NTT DATA CORPORATION
  *
- * Version: 1.8.0   2010/11/11
+ * Version: 1.8.0+   2010/12/31
  */
 
 #ifndef _SECURITY_CCSECURITY_INTERNAL_H
@@ -652,8 +652,7 @@ enum ccs_policy_stat_type {
 
 /* Index numbers for profile's PREFERENCE values. */
 enum ccs_pref_index {
-	CCS_PREF_MAX_GRANT_LOG,
-	CCS_PREF_MAX_REJECT_LOG,
+	CCS_PREF_MAX_AUDIT_LOG,
 	CCS_PREF_MAX_LEARNING_ENTRY,
 	CCS_PREF_ENFORCING_PENALTY,
 	CCS_MAX_PREF
@@ -667,8 +666,7 @@ enum ccs_proc_interface_index {
 	CCS_PROCESS_STATUS,
 	CCS_MEMINFO,
 	CCS_STAT,
-	CCS_GRANTLOG,
-	CCS_REJECTLOG,
+	CCS_AUDIT,
 	CCS_VERSION,
 	CCS_PROFILE,
 	CCS_QUERY,
@@ -748,12 +746,10 @@ enum ccs_value_type {
 #define CCS_OPEN_FOR_IOCTL_ONLY           2
 /* Current thread is doing do_execve() ? */
 #define CCS_TASK_IS_IN_EXECVE             4
-/* Current thread should not be carried sleep penalty? */
-#define CCS_DONT_SLEEP_ON_ENFORCE_ERROR   8
 /* Current thread is running as an execute handler program? */
-#define CCS_TASK_IS_EXECUTE_HANDLER      16
-/* Curren thread is allowed to modify policy via /proc/ccs/ interface? */
-#define CCS_TASK_IS_MANAGER              32
+#define CCS_TASK_IS_EXECUTE_HANDLER       8
+/* Current thread is allowed to modify policy via /proc/ccs/ interface? */
+#define CCS_TASK_IS_MANAGER              16
 
 /*
  * Retry this request. Returned by ccs_supervisor() if policy violation has
@@ -1032,6 +1028,8 @@ struct ccs_request_info {
 	} param;
 	u8 param_type; /* One of values in "enum ccs_acl_entry_type_index". */
 	bool granted; /* True if granted, false otherwise. */
+	/* True if current thread should not be carried sleep penalty. */
+	bool dont_sleep_on_enforce_error;
 	/*
 	 * For updating current->ccs_domain_info at ccs_update_task_domain().
 	 * Initialized to NULL at ccs_init_request_info().
@@ -1422,6 +1420,7 @@ char *ccs_init_log(struct ccs_request_info *r, int len, const char *fmt,
 		   va_list args);
 char *ccs_read_token(struct ccs_acl_param *param);
 char *ccs_realpath_from_path(struct path *path);
+const char *ccs_yesno(const unsigned int value);
 const char *ccs_get_exe(void);
 const struct ccs_path_info *ccs_compare_name_union
 (const struct ccs_path_info *name, const struct ccs_name_union *ptr);
